pygeodesy.karney._CapsBase

Package pygeodesy :: Module karney :: Class _CapsBase |
[frames] | no frames]

# Class _CapsBase

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
                      _CapsBase

Known Subclasses:
  - _kWrapped
  - , solveBase._SolveCapsBase
  - , geodesicx.gxbases._GeodesicBase
  - , rhumb.bases.RhumbBase
  - , rhumb.bases.RhumbLineBase

(INTERNAL) Base class for `Geodesic*`, `Geodesic*Exact`, `Intersectool` and `Rhumb*Base`.

Instance Methods
caps_(self, caps) Check the available capabilities. |
Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr`, `toStr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables
| ALL = `32671`
| AREA = `16400`
| AZIMUTH = `512`
| DISTANCE = `1025`
| DISTANCE_IN = `2051`
| EMPTY = `0` hash(x)
| GEODESICSCALE = `8197`
| LATITUDE = `128`
| LINE_CAPS = `16271`
| LINE_OFF = `65536`
| LONGITUDE = `264`
| LONG_UNROLL = `32768`
| NONFINITONAN = `131072`
| REDUCEDLENGTH = `4101`
| STANDARD = `1929`
| STANDARD_LINE = `3979`

Properties
| caps Get the capabilities (bit-or'ed `Caps`).
| debug Get the `debug` option (`bool`).
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### caps_ (self, caps) |
Check the available capabilities. Arguments: `caps` - Bit-or'ed combination of Caps values for all capabilities to be checked. Returns: `True` if all `caps` are available, `False` otherwise (`bool`).

Property Details

### caps Get the capabilities (bit-or'ed `Caps`). Get method: caps(self) - Get the capabilities (bit-or'ed `Caps`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### debug Get the `debug` option (`bool`). Get method: debug(self) - Get the `debug` option (`bool`). Set method: debug(self, debug) - Set the `debug` option (`bool`) to include more details in GDict results.